program ex1_elapsed_time
!
!
! Purpose
! =======
!
!   This program is intended to demonstrate the use of function ELAPSED_TIME
!   in module Time_Procedures for computing the elapsed time between two times.
!
!
! LATEST REVISION : 01/12/2023
!
! ================================================================================================
!
!
! USED MODULES 
! ============
!
    use Statpack, only : i4b, elapsed_time
!   
!
! STRONG TYPING IMPOSED
! =====================
!    
    implicit none
!   
!   
! PARAMETERS 
! ==========
!
! prtunit IS THE PRINTING UNIT.
!
    integer(i4b), parameter :: prtunit=6
!
    character(len=*), parameter :: name_proc='Example 1 of elapsed_time'
!   
!
! SPECIFICATIONS FOR VARIABLES
! ============================
!
    integer,      dimension(7) :: t1, t0
    integer(i4b)               :: i, j
!
    character(len=13) :: string
!   
!
! EXECUTABLE STATEMENTS
! =====================
!
!   PRINT LABEL OF THE EXAMPLE.
!
    write (prtunit,*)
    write (prtunit,*) name_proc,' :'
    write (prtunit,*) repeat('*', len(name_proc) )
    write (prtunit,*)
!
!   FUNCTION elapsed_time COMPUTES ELAPSED TIME BETWEEN TWO INVOCATIONS OF THE INTRINSIC
!   FUNCTION DATE_AND_TIME. elapsed_time( T1, T0 ) RETURNS THE TIME IN SECONDS THAT HAS
!   ELAPSED BETWEEN THE VECTORS T0 AND T1. EACH VECTOR MUST HAVE AT LEAST SEVEN ELEMENTS
!   IN THE FORMAT RETURNED BY DATE_AND_TIME FOR THE OPTIONAL ARGUMENT VALUES; NAMELY
!
!           T = (/ year, month, day, x, hour, minute, second /)
!
!   THIS FUNCTION WORKS ACROSS MONTH AND YEAR BOUNDARIES BUT DOES NOT CHECK
!   THE VALIDITY OF ITS ARGUMENTS, WHICH ARE EXPECTED TO BE OBTAINED AS IN
!   THE FOLLOWING EXAMPLE THAT SHOWS HOW TO TIME SOME OPERATION BY USING ELAPSED_TIME.
!
!   THIS ROUTINE WORKS ALSO PROPERLY WITH OPENMP.
!
    call date_and_time( values=t0(:) )
    j = 0
    do i=1, 2000000000
        j = j + 1
    end do
    call date_and_time( values=t1(:) )
!
!   PRINT THE RESULT.
!
    write (prtunit, *)  'Elapsed Time (s): ', elapsed_time( t1(:), t0(:) )
!
!
! END OF PROGRAM ex1_elapsed_time
! ===============================
!
end program ex1_elapsed_time
